################
 repeated_dates
################

The generale format of the `repeated_dates` source is:

.. literalinclude:: yaml/repeated_dates1.yaml
   :language: yaml

**********
 constant
**********

.. literalinclude:: yaml/repeated_dates2.yaml
   :language: yaml

*************
 climatology
*************

.. literalinclude:: yaml/repeated_dates3.yaml
   :language: yaml

*********
 closest
*********

.. literalinclude:: yaml/repeated_dates4.yaml
   :language: yaml
